Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(514)

Unified Diff: services/ui/ws/display.h

Issue 2712203002: c++ / mojo changes for 'external window mode'
Patch Set: addressed sky/fwang feedback (take 5), simpler mus_demo changes / passing unittests Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: services/ui/ws/display.h
diff --git a/services/ui/ws/display.h b/services/ui/ws/display.h
index 2fae94d743b8df52b14bc9267ddc2b1df7b6fd94..a47b4e193825336a8b9f5e49f4dceab1557365e5 100644
--- a/services/ui/ws/display.h
+++ b/services/ui/ws/display.h
@@ -152,7 +152,11 @@ class Display : public PlatformDisplayDelegate,
using WindowManagerDisplayRootMap =
std::map<UserId, WindowManagerDisplayRoot*>;
- // Inits the necessary state once the display is ready.
+ // Inits the display root once the display is ready in
+ // 'external window mode'.
+ void InitDisplayRoot();
+
+ // Inits the necessary WindowManager state once the display is ready.
void InitWindowManagerDisplayRoots();
// Creates the set of WindowManagerDisplayRoots from the
@@ -204,6 +208,8 @@ class Display : public PlatformDisplayDelegate,
WindowManagerDisplayRootMap window_manager_display_root_map_;
+ std::unique_ptr<WindowManagerDisplayRoot> external_window_mode_display_root_;
kylechar 2017/03/07 18:19:37 |external_mode_root_| maybe?
tonikitoo 2017/03/07 20:09:36 Will fix.
+
DISALLOW_COPY_AND_ASSIGN(Display);
};

Powered by Google App Engine
This is Rietveld 408576698